package com.example.shoesapptest.ui

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.lifecycle.ViewModelProvider
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.shoesapp.ui.theme.MatuleTheme
import com.example.shoesapptest.AuthRemoteSourceImpl
import com.example.shoesapptest.RegistrationViewModelFactory
import com.example.shoesapptest.data.local.datastore.LocalDataStore
import com.example.shoesapptest.data.repository.AuthRepositoryImpl
import com.example.shoesapptest.screen.RegistrationScreen
import com.example.shoesapptest.screen.TestScreen
import com.example.shoesapptest.screen.registrationscreen.RegistrationViewModel



class MainActivity : ComponentActivity() {
    private lateinit var authLocalStore: LocalDataStore
    private lateinit var authRemoteSource: AuthRemoteSourceImpl
    private lateinit var authRepository: AuthRepositoryImpl

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        // Инициализация зависимостей
        authLocalStore = LocalDataStore(applicationContext)
        authRemoteSource = AuthRemoteSourceImpl()
        authRepository = AuthRepositoryImpl(authLocalStore, authRemoteSource)

        setContent {
            MatuleTheme {
                val navController = rememberNavController()
                NavHost(
                    navController = navController,
                    startDestination = "register"
                ) {
                    composable("register") {
                        // Создание и передача ViewModel
                        val registrationViewModel: RegistrationViewModel = ViewModelProvider(
                            this@MainActivity,
                            RegistrationViewModelFactory(authRepository)
                        ).get(RegistrationViewModel::class.java)

                        RegistrationScreen(
                            navController = navController,
                            registrationViewModel = registrationViewModel
                        )
                    }

                    composable("test") {
                        TestScreen()
                    }
                }
            }
        }
    }
}

