package com.example.shoesapptest.screen

import androidx.compose.foundation.background
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.text.ClickableText
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.Checkbox
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.IconButton
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import com.example.shoesapptest.R
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.AnnotatedString
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.navigation.NavController
import com.example.shoesapp.ui.theme.MatuleTheme
import com.example.shoesapptest.screen.forgotscreen.component.TitleWithSubtitleText
import com.example.shoesapptest.screen.registrationscreen.RegistrationViewModel
import com.example.shoesapptest.screen.registrationscreen.component.RegistrationBtn
import com.example.shoesapptest.screen.registrationscreen.component.RegistrationTextField

@Composable
fun RegistrationScreen(
    navController: NavController,
    registrationViewModel: RegistrationViewModel
){
    Scaffold(
        topBar = {
            Row(
                modifier = Modifier
                    .padding(top = 35.dp)
                    .fillMaxWidth()
                    .height(40.dp)
            ){
                IconButton(onClick={}) {
                    Icon(painter = painterResource(R.drawable.back_arrow),
                        contentDescription = null)
                }
            }
        },
        bottomBar = {
            Row(
                horizontalArrangement = Arrangement.Center,
                verticalAlignment = Alignment.CenterVertically,
                modifier = Modifier
                    .padding(bottom = 50.dp)
                    .fillMaxWidth()
                    .height(40.dp)
            ) {
                Text(
                    text= stringResource(R.string.sign_in_on_reg),
                    style=MatuleTheme.typography.bodyRegular16.copy(MatuleTheme.colors.text),
                    textAlign = TextAlign.Center
                )
            }
        }
    ) { paddingValues ->
        RegistrationScreen(
            paddingValues=paddingValues,
            registrationViewModel=registrationViewModel,
            onRegistrationSuccess = {navController.navigate("test")},
            onRegistrationError = {errorMessage -> }
        )
    }
}

@Composable
fun RegistrationScreen(paddingValues: PaddingValues,
                       registrationViewModel: RegistrationViewModel,
                       onRegistrationSuccess: () -> Unit,
                       onRegistrationError: (String) -> Unit){
    val register = registrationViewModel.registration

    Column(
        modifier = Modifier
            .fillMaxWidth()
            .padding(20.dp)
    ) {
        TitleWithSubtitleText(
            title = "Регистрация",
            subTitle = "Заполните Свои данные или продолжите через социальные медиа"
        )

        Spacer(modifier = Modifier.height(20.dp))

        RegistrationTextField(
            value = register.value.name,
            onChangeValue = { registrationViewModel.setUserName(it) },
            isError = false,
            supportingText = { Text(text = stringResource(R.string.wrong_name)) },
            placeholder = { Text(text = stringResource(R.string.template_name)) },
            label = { Text(text = stringResource(R.string.name)) }
        )
        RegistrationTextField(
            value = register.value.email,
            onChangeValue = { registrationViewModel.setEmail(it) },
            isError = registrationViewModel.emailHasError.value,
            supportingText = { Text(text = stringResource(R.string.wrong_email)) },
            placeholder = { Text(text = stringResource(R.string.template_email)) },
            label = { Text(text = stringResource(R.string.email)) }
        )
        RegistrationTextField(
            value = register.value.password,
            onChangeValue = { registrationViewModel.setPassword(it) },
            isError = false,
            supportingText = { Text(text = stringResource(R.string.wrong_password)) },
            placeholder = { Text(text = stringResource(R.string.template_password)) },
            label = { Text(text = stringResource(R.string.password)) }
        )

        SimpleCheckbox()

        RegistrationBtn(onClick = {
            registrationViewModel.registration(
                onSuccess = {
                    onRegistrationSuccess()
                },
                onError = { errorMessage ->

                    onRegistrationError(errorMessage)
                }
            )
        }
        ) {
            Text(text = stringResource(R.string.sign_up_on_reg))
        }
    }
}

@Composable
fun SimpleCheckbox(){
    val isChecked = remember { mutableStateOf(false) }

    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = Modifier.fillMaxWidth()
            .padding(16.dp)
    ){
        Checkbox(
            checked = isChecked.value,
            onCheckedChange = {isChecked.value = it}
        )
        ClickableText(
            text = AnnotatedString(
                "Даю согласие на обработку персональных данных"
            ),
            onClick={},
            style = MatuleTheme.typography.bodyRegular16.copy(color = MatuleTheme.colors.text),
            modifier = Modifier.padding(start = 8.dp)
        )
    }
}















