package com.example.shoesapptest.screen.registrationscreen

import androidx.compose.animation.core.animateDecay
import androidx.compose.runtime.derivedStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.shoesapptest.data.model.RegistrationRequest
import com.example.shoesapptest.data.repository.AuthRepository
import kotlinx.coroutines.launch
import java.lang.Error

class RegistrationViewModel(
    private val authRepository: AuthRepository
):ViewModel() {
    var registration = mutableStateOf(Registration())
        private set
    val emailHasError = derivedStateOf {
        if (registration.value.email.isEmpty()) return@derivedStateOf false
        !android.util.Patterns.EMAIL_ADDRESS.matcher(registration.value.email).matches()
    }
    fun setEmail(email: String){
        registration.value=registration.value.copy(email=email)
    }
    fun setPassword(password: String){
        registration.value = registration.value.copy(password=password)
    }
    fun setUserName(name: String){
        registration.value = registration.value.copy(name=name)
    }
    fun registration(onSuccess: () -> Unit, onError: (String) -> Unit){
        viewModelScope.launch {
            try {
                val registrationRequest = RegistrationRequest(
                    userName = registration.value.name,
                    email = registration.value.email,
                    password = registration.value.password
                )

                authRepository.registration(registrationRequest)
                onSuccess()
            } catch (e: Exception) {
                onError(e.message ?: "Ошибка регистрации")
            }
        }
    }
}